/*
   SPDX-FileCopyrightText: 2016-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once
#include <PimCommon/ConfigurePluginsWidget>

class KAddressBookConfigPluginListWidget : public TextAddonsWidgets::ConfigurePluginsWidget
{
    Q_OBJECT
public:
    explicit KAddressBookConfigPluginListWidget(QWidget *parent = nullptr);
    ~KAddressBookConfigPluginListWidget() override;

    void save() override;
    void doLoadFromGlobalSettings() override;
    void doResetToDefaultsOther() override;
    void initialize() override;

private:
    void slotConfigureClicked(const QString &configureGroupName, const QString &identifier);
    QList<PluginItem *> mPluginGenericItems;
    QList<PluginItem *> mPluginImportExportItems;
};
